==> selenium_profiles-2.2.4.tar.gz: selenium_profiles-2.2.4/build_upload.md <==
## Build dist
```shell
python setup.py sdist
```

## Upload to pypi
```shell
twine upload dist/*
```
#### Username
```
kaliiiiiiiiii
```

## install all python versions from dir
```shell
# 3.7
C:\Users\aurin\PycharmProjects\selenium_profiles\venv\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.8
C:\Users\aurin\PycharmProjects\selenium_profiles\venv38\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.9
C:\Users\aurin\PycharmProjects\selenium_profiles\venv39\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.10
C:\Users\aurin\PycharmProjects\selenium_profiles\venv310\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.11
C:\Users\aurin\PycharmProjects\selenium_profiles\venv311\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```

## install all python versions from pypi
```shell
# 3.7
C:\Users\aurin\PycharmProjects\selenium_profiles\venv\Scripts\pip.exe install selenium-profiles
# 3.8
C:\Users\aurin\PycharmProjects\selenium_profiles\venv38\Scripts\pip.exe selenium-profiles
# 3.9
C:\Users\aurin\PycharmProjects\selenium_profiles\venv39\Scripts\pip.exe selenium-profiles
# 3.10
C:\Users\aurin\PycharmProjects\selenium_profiles\venv310\Scripts\pip.exe install selenium-profiles
# 3.11
C:\Users\aurin\PycharmProjects\selenium_profiles\venv311\Scripts\pip.exe install selenium-profiles
```

## install from GitHub
```shell
pip install https://github.com/kaliiiiiiiiii/Selenium-Profiles/archive/refs/heads/master.zip
```

==> selenium_profiles-2.2.4.4.tar.gz: selenium_profiles-2.2.4.4/build_upload.md <==
## Build dist
```shell
python setup.py sdist
```

## Upload to pypi
```shell
twine upload dist/*
```
#### Username
```
kaliiiiiiiiii
```

## install all python versions from dir
```shell
# 3.7
C:\Users\aurin\PycharmProjects\selenium_profiles\venv\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.8
C:\Users\aurin\PycharmProjects\selenium_profiles\venv38\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.9
C:\Users\aurin\PycharmProjects\selenium_profiles\venv39\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.10
C:\Users\aurin\PycharmProjects\selenium_profiles\venv310\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
# 3.11
C:\Users\aurin\PycharmProjects\selenium_profiles\venv311\Scripts\pip.exe install C:\Users\aurin\PycharmProjects\selenium_profiles
```

## install all python versions from pypi
```shell
# 3.7
C:\Users\aurin\PycharmProjects\selenium_profiles\venv\Scripts\pip.exe install --no-cache-dir selenium_profiles
# 3.8
C:\Users\aurin\PycharmProjects\selenium_profiles\venv38\Scripts\pip.exe install --no-cache-dir selenium-profiles
# 3.9
C:\Users\aurin\PycharmProjects\selenium_profiles\venv39\Scripts\pip.exe  install --no-cache-dir selenium-profiles
# 3.10
C:\Users\aurin\PycharmProjects\selenium_profiles\venv310\Scripts\pip.exe install --no-cache-dir selenium-profiles
# 3.11
C:\Users\aurin\PycharmProjects\selenium_profiles\venv311\Scripts\pip.exe install --no-cache-dir selenium-profiles
```

## install from GitHub
```shell
pip install https://github.com/kaliiiiiiiiii/Selenium-Profiles/archive/refs/heads/master.zip
```
